# Ortus PDF Extension

The Ortus PDF Lucee Extension adds to any Lucee engine the missing PDF capabilities you were longing for and enhancing some PDF capabilities as well. The extension contains several new CFML built-in tags and functions (coming soon) that will help you manipulate and work with PDF documents.  You can read more about this extension here: [https://www.ortussolutions.com/products/ortuspdf](https://www.ortussolutions.com/products/ortuspdf)

## Requirements

* Lucee 5.x

## Implemented Tags

The following are the implemented tags that bring compatibility from Adobe ColdFusion to Lucee.  You can see much more detailed information about these tags here: https://helpx.adobe.com/coldfusion/cfml-reference/coldfusion-tags/tags-p-q/cfpdfform.html

* `cfpdfform` - https://cfdocs.org/cfpdfform
* `cfpdfformparam` - https://cfdocs.org/cfpdfformparam

## Capabilities

* <code>cfpdfform</code> tag implementation compliant with Adobe ColdFusion
* <code>cfpdfformparam</code> tag implementation compliant with Adobe ColdFusion
* Ability to export PDF form data into:
    * Native CFML Structures
    * XML String
    * XML File
    * FDF File
    * JSON
* Ability to pre-fill PDF form data from:
    * Native CFML Structures
    * XML String
    * XML File
    * XML Objects
    * JSON objects
* Allows the ability to flatten PDFs after populating them with data
* Manipulates existing forms created in Adobe® Acrobat® and Adobe® LiveCycle® Designer
* Ability to stream generated PDFs to browser
* Ability to read subforms or embedded forms (since version 2.1.0)
* Much More!!

## Quick Usage

### Populate Using Native CFML Structs

```
data = {
    "full_name" = "Ortus Rocks",
    "exam_date" = "#dateFormat( now(), "mmmm dd, yyyy")# #timeFormat( now(), "medium")#",
    "strategy_overview" = "Drink a lot of water!",
    "strategy_tips"	= "Eat a lot of cheese!"
};
pdfform 
    action="populate" 
    source="#datapath#/report.pdf" 
    overwrite="true"
    overwriteData="true"
    structData=data
    flatten="true";
```

### Populate Using JSON

```
jsonData = '{
    "full_name"	: "Ortus Rocks",
    "exam_date"	: "#dateFormat( now(), "mmmm dd, yyyy")# #timeFormat( now(), "medium")#",
    "strategy_overview" : "Drink a lot of water!",
    "strategy_tips" : "Eat a lot of cheese!"
}';
pdfform 
    action="populate" 
    source="#datapath#/report.pdf" 
    overwrite="true"
    overwriteData="true"
    jsonData="#jsonData#"
    flatten="true";
```

### Reading a PDF Form

```
pdfform 
    action="read"
    source="#dataPath#/report.pdf"
    result="formData"
    jsonData="jsonData";
// Native Struct
writeDump( formData );
// JSON Data
writeDump( jsonData );
```